@@ -2,6 +2,6 @@ from .black_box_optimization import BlackBoxOptimization
 from .rwr import RWR
 from .reps import REPS
 from .pgpe import PGPE
+from .constrained_reps import ConstrainedREPS
 
-
-__all__ = ['RWR', 'PGPE', 'REPS']
\ No newline at end of file
+__all__ = ['RWR', 'PGPE', 'REPS', 'ConstrainedREPS']
\ No newline at end of file
