@@ -3,7 +3,7 @@ from collections import deque
 
 import gym
 
-from mushroom_rl.environments import Environment, MDPInfo
+from mushroom_rl.core import Environment, MDPInfo
 from mushroom_rl.utils.spaces import *
 from mushroom_rl.utils.frames import LazyFrames, preprocess_frame
 
